==> salesforce-graphql-0.0.1.tgz: package/examples/demo.ts <==
const jsforce = require('jsforce');
require('dotenv').config();
import { GraphQLServer } from 'graphql-yoga';
import { IDirectiveResolvers } from 'graphql-tools';
const express = require('express');
const bodyParser = require('body-parser');
const { graphqlExpress, graphiqlExpress } = require('apollo-server-express');
const { makeExecutableSchema } = require('graphql-tools');
const path = require('path');
const fs = require('fs');
const schemaFile = path.join(__dirname, 'schema.graphql');
const typeDefs = fs.readFileSync(schemaFile, 'utf8');

const { Salesforce } = require('../src');

const resolvers = {
  Query: {
    Accounts: (parent, args, context, info) => context.db.query({}, info).then(res => res.records),
    Account: (parent, args, context, info) =>
      context.db.query({}, info).then(res => res.records[0]),
    Contacts: (parent, args, context, info) => context.db.query({}, info).then(res => res.records),
    Contact: (parentobj, args, context, info) =>
      context.db.query({}, info).then(res => res.records[0]),
  },
};

const conn = new jsforce.Connection({});
conn.login(process.env.SALESFORCE_USERNAME, process.env.SALESFORCE_PASSWORD, (err, userinfo) => {
  init(conn);
});

function init(conn) {
  const client = new Salesforce({ conn });
  // Put together a schema
  const server = new GraphQLServer({
    typeDefs,
    resolvers,
    context: req => ({
      ...req,
      db: client,
    }),
  });

  server.start({ playground: '/playground' }, ({ port }) =>
    console.log('Server is running on localhost:' + port)
  );
}

==> salesforce-graphql-0.0.2.tgz: package/examples/demo.ts <==
const jsforce = require('jsforce');
require('dotenv').config();
import { GraphQLServer } from 'graphql-yoga';
import { IDirectiveResolvers } from 'graphql-tools';
const express = require('express');
const bodyParser = require('body-parser');
const { graphqlExpress, graphiqlExpress } = require('apollo-server-express');
const { makeExecutableSchema } = require('graphql-tools');
const path = require('path');
const fs = require('fs');
const schemaFile = path.join(__dirname, 'schema.graphql');
const typeDefs = fs.readFileSync(schemaFile, 'utf8');

const { Salesforce } = require('../src');

const resolvers = {
  Query: {
    Accounts: (parent, args, context, info) => context.db.query({}, info).then(res => res.records),
    Account: (parent, args, context, info) =>
      context.sf.query({}, info).then(res => res.records[0]),
    Contacts: (parent, args, context, info) => context.db.query({}, info).then(res => res.records),
    Contact: (parentobj, args, context, info) =>
      context.sf.query({}, info).then(res => res.records[0]),
  },
  Account: {
    Contacts: (parent, args, context, info) =>
      context.sf.query({ AccountId: parent.Id }, info).then(res => res.records),
  },
  Contact: {
    Account: (parent, args, context, info) =>
      context.sf.query({ Id: parent.AccountId }, info).then(res => res.records[0]),
  },
};

const sf = new jsforce.Connection({});
sf.login(process.env.SALESFORCE_USERNAME, process.env.SALESFORCE_PASSWORD, (err, userinfo) => {
  init();
});

function init() {
  const client = new Salesforce({ sf });
  // Put together a schema
  const server = new GraphQLServer({
    typeDefs,
    resolvers,
    context: req => ({ ...req, sf }),
  });

  server.start({ playground: '/playground' }, ({ port }) =>
    console.log('Server is running on localhost:' + port)
  );
}
